@@ -28,7 +28,7 @@ import prance
 from dictor import dictor
 from itertools import combinations
 
-from CVApiAnalyser import CommunityEdition
+from cvapianalyser import CommunityEdition
 from openapispecdiff import OpenApiSpecDiff
 
 import urllib3
@@ -260,7 +260,7 @@ class CloudvectorDAST(object):
                     self.response_schema_to_validate[api] = {"200":{}}
                 if method not in self.response_schema_to_validate[api]["200"]:
                     self.response_schema_to_validate[api]["200"][method] = {}
-                print(api, method, minfo,"\n\n")
+                #print(api, method, minfo,"\n\n")
                 for ky in key_lookup("schema", minfo):
                     if "200" in ky and ".required" in ky:
                         self.response_schema_to_validate[api]["200"][method] = dictor(minfo, ky)
